DeleteSessionResponse class

Constructors

DeleteSessionResponse({String? botAlias, String? botName, String? sessionId, String? userId})
DeleteSessionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

botAlias → String?
The alias in use for the bot associated with the session data.
final
botName → String?
The name of the bot associated with the session data.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → String?
The unique identifier for the session.
final
userId → String?
The ID of the client application user.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited