GenericAttachment class

Represents an option rendered to the user when a prompt is shown. It could be an image, a button, a link, or text.

Constructors

GenericAttachment({String? attachmentLinkUrl, List<Button>? buttons, String? imageUrl, String? subTitle, String? title})
GenericAttachment.fromJson(Map<String, dynamic> json)
factory

Properties

attachmentLinkUrl → String?
The URL of an attachment to the response card.
final
buttons → List<Button>?
The list of options to show to the user.
final
hashCode → int
The hash code for this object.
no setterinherited
imageUrl → String?
The URL of an image that is displayed to the user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subTitle → String?
The subtitle shown below the title.
final
title → String?
The title of the option.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited