GetSessionResponse class

Constructors

GetSessionResponse({List<ActiveContext>? activeContexts, DialogAction? dialogAction, List<IntentSummary>? recentIntentSummaryView, Map<String, String>? sessionAttributes, String? sessionId})
GetSessionResponse.fromJson(Map<String, dynamic> json)
factory

Properties

activeContexts → List<ActiveContext>?
A list of active contexts for the session. A context can be set when an intent is fulfilled or by calling the PostContent, PostText, or PutSession operation.
final
dialogAction → DialogAction?
Describes the current state of the bot.
final
hashCode → int
The hash code for this object.
no setterinherited
recentIntentSummaryView → List<IntentSummary>?
An array of information about the intents used in the session. The array can contain a maximum of three summaries. If more than three intents are used in the session, the recentIntentSummaryView operation contains information about the last three intents used.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionAttributes → Map<String, String>?
Map of key/value pairs representing the session-specific context information. It contains application information passed between Amazon Lex and a client application.
final
sessionId → String?
A unique identifier for the session.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited