PostContentResponse class

Constructors

PostContentResponse({Object? activeContexts, Object? alternativeIntents, Uint8List? audioStream, String? botVersion, String? contentType, DialogState? dialogState, String? inputTranscript, String? intentName, String? message, MessageFormatType? messageFormat, Object? nluIntentConfidence, String? sentimentResponse, Object? sessionAttributes, String? sessionId, String? slotToElicit, Object? slots})

Properties

activeContexts → Object?
A list of active contexts for the session. A context can be set when an intent is fulfilled or by calling the PostContent, PostText, or PutSession operation.
final
alternativeIntents → Object?
One to four alternative intents that may be applicable to the user's intent.
final
audioStream → Uint8List?
The prompt (or statement) to convey to the user. This is based on the bot configuration and context. For example, if Amazon Lex did not understand the user intent, it sends the clarificationPrompt configured for the bot. If the intent requires confirmation before taking the fulfillment action, it sends the confirmationPrompt. Another example: Suppose that the Lambda function successfully fulfilled the intent, and sent a message to convey to the user. Then Amazon Lex sends that message in the response.
final
botVersion → String?
The version of the bot that responded to the conversation. You can use this information to help determine if one version of a bot is performing better than another version.
final
contentType → String?
Content type as specified in the Accept HTTP header in the request.
final
dialogState → DialogState?
Identifies the current state of the user interaction. Amazon Lex returns one of the following values as dialogState. The client can optionally use this information to customize the user interface.
final
hashCode → int
The hash code for this object.
no setterinherited
inputTranscript → String?
The text used to process the request.
final
intentName → String?
Current user intent that Amazon Lex is aware of.
final
message → String?
The message to convey to the user. The message can come from the bot's configuration or from a Lambda function.
final
messageFormat → MessageFormatType?
The format of the response message. One of the following values:
final
nluIntentConfidence → Object?
Provides a score that indicates how confident Amazon Lex is that the returned intent is the one that matches the user's intent. The score is between 0.0 and 1.0.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sentimentResponse → String?
The sentiment expressed in an utterance.
final
sessionAttributes → Object?
Map of key/value pairs representing the session-specific context information.
final
sessionId → String?
The unique identifier for the session.
final
slots → Object?
Map of zero or more intent slots (name/value pairs) Amazon Lex detected from the user input during the conversation. The field is base-64 encoded.
final
slotToElicit → String?
If the dialogState value is ElicitSlot, returns the name of the slot for which Amazon Lex is eliciting a value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited