PutSessionResponse class

Constructors

PutSessionResponse({Object? activeContexts, Uint8List? audioStream, String? contentType, DialogState? dialogState, String? intentName, String? message, MessageFormatType? messageFormat, Object? sessionAttributes, String? sessionId, String? slotToElicit, Object? slots})

Properties

activeContexts → Object?
A list of active contexts for the session.
final
audioStream → Uint8List?
The audio version of the message to convey to the user.
final
contentType → String?
Content type as specified in the Accept HTTP header in the request.
final
dialogState → DialogState?
final
hashCode → int
The hash code for this object.
no setterinherited
intentName → String?
The name of the current intent.
final
message → String?
The next message that should be presented to the user.
final
messageFormat → MessageFormatType?
The format of the response message. One of the following values:
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionAttributes → Object?
Map of key/value pairs representing session-specific context information.
final
sessionId → String?
A unique identifier for the session.
final
slots → Object?
Map of zero or more intent slots Amazon Lex detected from the user input during the conversation.
final
slotToElicit → String?
If the dialogState is ElicitSlot, returns the name of the slot for which Amazon Lex is eliciting a value.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited